.. unify:

.. default-domain:: py

Unify interfaces
================


Unify
*****

.. autoclass:: unify_idents.unify.Unify
    :members:
    :exclude-members: __iter__, __next__

    .. automethod:: _get_parser_classes

    .. automethod:: _get_parser

UnifiedDataFrame
****************

.. autoclass:: unify_idents.unify.UnifiedDataFrame
    :members:
    :exclude-members: __iter__, __next__
    :show-inheritance:
    :member-order: bysource


UnifiedRow
**********

.. autoclass:: unify_idents.unify.UnifiedRow
    :members:
    :show-inheritance:
    :member-order: bysource
